==> apache-livy-0.8.0-incubating-src.zip: apache-livy-0.8.0-incubating/server/src/test/scala/org/apache/livy/sessions/MockSession.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.livy.sessions

import org.apache.livy.LivyConf

class MockSession(id: Int, owner: String, conf: LivyConf, name: Option[String] = None,
                  ttl: Option[String] = None)
  extends Session(id, name, owner, ttl, conf) {
  case class RecoveryMetadata(id: Int) extends Session.RecoveryMetadata()

  override val proxyUser = None

  override def start(): Unit = ()

  var stopped = false
  override protected def stopSession(): Unit = {
    stopped = true
  }

  override def logLines(): IndexedSeq[String] = IndexedSeq()

  var serverState: SessionState = SessionState.Idle
  override def state: SessionState = serverState

  override def recoveryMetadata: RecoveryMetadata = RecoveryMetadata(0)
}

==> apache-livy-0.9.0-incubating-src.zip: apache-livy-0.9.0-incubating/server/src/test/scala/org/apache/livy/sessions/MockSession.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.livy.sessions

import org.apache.livy.LivyConf

class MockSession(id: Int, owner: String, conf: LivyConf, name: Option[String] = None,
                  ttl: Option[String] = None, idleTimeout: Option[String] = None)
  extends Session(id, name, owner, ttl, idleTimeout, conf) {
  case class RecoveryMetadata(id: Int) extends Session.RecoveryMetadata()

  override val proxyUser = None

  override def start(): Unit = {
    startedOn = Some(System.nanoTime())
  }

  var stopped = false
  override protected def stopSession(): Unit = {
    stopped = true
  }

  override def logLines(): IndexedSeq[String] = IndexedSeq()

  var serverState: SessionState = SessionState.Idle
  override def state: SessionState = serverState

  override def recoveryMetadata: RecoveryMetadata = RecoveryMetadata(0)
}
